/***********************************************************************/
/*                                                                     */
/* RIGI Utilities --- Copyright (C) 1996-1999                          */
/*                    The Rigi Group, University of Victoria           */
/*                                                                     */
/* see the file license.terms for usage and copying policies           */
/*                                                                     */
/* Author: Johannes Martin (jmartin@csr.csc.uvic.ca)                   */
/*                                                                     */
/***********************************************************************/
class CodeStore2RSF : public CodeStoreParser {
  virtual void emit(const CS_String& elem0, const CS_String& elem1, const CS_String& elem2,
                    const CS_String& elem3, int line, int column);
};

void CodeStore2RSF::emit(const CS_String& elem0, const CS_String& elem1, const CS_String& elem2,
                         const CS_String& elem3, int line, int column) {
  RsfTuple(elem0.str(), elem1.str(), elem2.str(), elem3.str(), line, column).print(true);
}

int main(int argc, char* argv[])
{
  CS_String project;
  if (argc == 2) {
    project = argv[1];
  } else {
    cerr << "RIGI C++ Parser Using IBM VA C++ Codestore (cs2rsf) - " VERSION "\n";
    cerr << "Usage: " << argv[0] << " <project-description-file>" << endl;
    exit(-1);
  }

  // Create a Codestore, connect it to the sources listed in the project file.

  CS_CodeStore::ReturnValue r;
  CS_CodeStore* code_store;

  r = CS_CodeStore::createTransientDatabase(code_store,project.str());

  if (r != 0) {
    PrintCodeStoreError(r);
    cerr << endl;
    PauseBeforeQuitting();
    exit(1);
  }

  // Create a default incorporator.
  //
  CS_IncorporationController controller;

  // Customize the controller here.

  //  Load the database.
  //
  CS_bool succeeded = code_store->incorporate(controller);

  if (!succeeded) {
    CS_MessageList &l = code_store->messages();
    PrintMessages(l.first());
  }

  // Browse the CodeStore here.
  try {
    CodeStore2RSF().parse(*code_store);
  } catch (CS_Error& e) {
    cerr << "Caught exception: " << e.message() << endl;
  } catch (...) {
    cerr << "Uncaught exception!" << endl;
  }
}
